@@ -43,6 +43,7 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
         """
         self._open_time = self.open_time_default if open_time is None else open_time
         self._close_time = self.close_time_default if close_time is None else close_time
+        self._holidays = None
 
     @classmethod
     def factory(cls, name, open_time=None, close_time=None):
@@ -212,11 +213,13 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
 
         :return: CustomBusinessDay object of holidays
         """
-        return CustomBusinessDay(
+        if self._holidays is None:
+            self._holidays = CustomBusinessDay(
             holidays=self.adhoc_holidays,
             calendar=self.regular_holidays,
             weekmask=self.weekmask,
         )
+        return self._holidays
 
     def valid_days(self, start_date, end_date, tz='UTC'):
         """
@@ -233,7 +236,7 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
         """
         Generates the schedule DataFrame. The resulting DataFrame will have all the valid business days as the index
         and columns for the market opening datetime (market_open) and closing datetime (market_close). All time zones
-        are set to UTC by default. Setting the tz parameter will convert the columns to the desired timezone, 
+        are set to UTC by default. Setting the tz parameter will convert the columns to the desired timezone,
         such as 'America/New_York'
 
         :param start_date: start date
@@ -263,10 +266,10 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
         # Overwrite the special opens and closes on top of the standard ones.
         _overwrite_special_dates(_all_days, opens, _special_opens)
         _overwrite_special_dates(_all_days, closes, _special_closes)
-        
+
         result = DataFrame(index=_all_days.tz_localize(None), columns=['market_open', 'market_close'],
                          data={'market_open': opens, 'market_close': closes})
-        
+
         if self.break_start:
             result['break_start'] = days_at_time(_all_days, self.break_start, self.tz).tz_convert(tz)
             temp = result[['market_open', 'break_start']].max(axis=1)
@@ -274,7 +277,7 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
             result['break_end'] = days_at_time(_all_days, self.break_end, self.tz).tz_convert(tz)
             temp = result[['market_close', 'break_end']].min(axis=1)
             result['break_end'] = temp
-            
+
         return result
 
     @staticmethod
@@ -289,23 +292,43 @@ class MarketCalendar(metaclass=MarketCalendarMeta):
             if using bars and would like to include the last bar as a valid open date and time.
         :return: True if the timestamp is a valid open date and time, False if not
         """
-        date = timestamp.date()
+        date = pd.Timestamp(pd.Timestamp(timestamp).tz_convert('UTC').date())
         if date in schedule.index:
             if 'break_start' in schedule.columns:
                 if include_close:
-                    return (schedule.loc[date, 'market_open'] <= timestamp <= schedule.loc[date, 'break_start']) or \
-                           (schedule.loc[date, 'break_end'] <= timestamp <= schedule.loc[date, 'market_close'])
+                    return (schedule.at[date, 'market_open'] <= timestamp <= schedule.at[date, 'break_start']) or \
+                           (schedule.at[date, 'break_end'] <= timestamp <= schedule.at[date, 'market_close'])
                 else:
-                    return (schedule.loc[date, 'market_open'] <= timestamp < schedule.loc[date, 'break_start']) or \
-                           (schedule.loc[date, 'break_end'] <= timestamp < schedule.loc[date, 'market_close'])
+                    return (schedule.at[date, 'market_open'] <= timestamp < schedule.at[date, 'break_start']) or \
+                           (schedule.at[date, 'break_end'] <= timestamp < schedule.at[date, 'market_close'])
             else:
                 if include_close:
-                    return schedule.loc[date, 'market_open'] <= timestamp <= schedule.loc[date, 'market_close']
+                    return schedule.at[date, 'market_open'] <= timestamp <= schedule.at[date, 'market_close']
                 else:
-                    return schedule.loc[date, 'market_open'] <= timestamp < schedule.loc[date, 'market_close']
+                    return schedule.at[date, 'market_open'] <= timestamp < schedule.at[date, 'market_close']
         else:
             return False
 
+    # need this to make is_open_now testable
+    @staticmethod
+    def _get_current_time():
+        return pd.Timestamp.now(tz='UTC')
+
+    @staticmethod
+    def is_open_now(schedule, include_close=False):
+        """
+        To determine if the current local system time (converted to UTC) is an open time for the market
+
+        :param schedule: schedule DataFrame
+        :param include_close: if False then the function will return False if the current local system time is equal to
+            the closing timestamp. If True then it will return True if the current local system time is equal to the
+            closing timestamp. Use True if using bars and would like to include the last bar as a valid open date
+            and time.
+        :return: True if the current local system time is a valid open date and time, False if not
+        """
+        current_time = MarketCalendar._get_current_time()
+        return MarketCalendar.open_at_time(schedule, current_time)
+
     def early_closes(self, schedule):
         """
         Get a DataFrame of the dates that are an early close.
